This function performs separate analysis (only taking into account concurrent controls) using a linear model and adjusting for periods, if the treatment arm stays in the trial for more than one period.
sepmodel_adj_cont(data, arm, alpha = 0.025, check = TRUE, ...)List containing the following elements regarding the results of comparing arm to control:
p-val - p-value (one-sided)
treat_effect - estimated treatment effect in terms of the difference in means
lower_ci - lower limit of the (1-2*alpha)*100% confidence interval
upper_ci - upper limit of the (1-2*alpha)*100% confidence interval
reject_h0 - indicator of whether the null hypothesis was rejected or not (p_val < alpha)
model - fitted model
Data frame with trial data, e.g. result from the datasim_cont() function. Must contain columns named 'treatment', 'response' and 'period'.
Integer. Index of the treatment arm under study to perform inference on (vector of length 1). This arm is compared to the control group.
Double. Significance level (one-sided). Default=0.025.
Logical. Indicates whether the input parameters should be checked by the function. Default=TRUE, unless the function is called by a simulation function, where the default is FALSE.
Further arguments passed by wrapper functions when running simulations.
Pavla Krotka
The adjusted separate analysis takes into account only the data from the evaluated experimental treatment arm and its concurrent controls and adjusts for the time effect by including the factor period (defined as a time interval bounded by any treatment arm entering or leaving the platform). The time is then modelled as a step-function with jumps at the beginning of each period. Denoting by \(y_j\) the response probability for patient \(j\), by \(k_j\) the arm patient \(j\) was allocated to, and by \(M\) the treatment arm under evaluation, the regression model is given by:
$$E(y_j) = \eta_0 + \theta_M \cdot I(k_j=M) + \sum_{s=S_{M_1}+1}^{S_{M_2}} \tau_s \cdot I(t_j \in T_{S_s})$$
where \(\eta_0\) is the response in the concurrent controls; \(\theta_M\) represents the treatment effect of treatment \(M\) as compared to control; \(\tau_s\) indicates the stepwise period effect between periods \(S_{M_1}\) and \(s\) (\(s = S_{M_1}+1, \ldots, S_{M_2}\)), where \(S_{M_1}\) and \(S_{M_2}\) denote the periods, in which the investigated treatment arm joined and left the trial, respectively.
If the data consists of only one period, the period in not used as covariate.
trial_data <- datasim_cont(num_arms = 3, n_arm = 100, d = c(0, 100, 250),
theta = rep(0.25, 3), lambda = rep(0.15, 4), sigma = 1, trend = "linear")
sepmodel_adj_cont(data = trial_data, arm = 3)
Run the code above in your browser using DataLab