piecewise_cal_cont: Model-based analysis for continuous data using discontinuous piecewise polynomials per calendar time unit
Description
This function performs linear regression taking into account all trial data until the arm under study leaves the trial and adjusting for time using discontinuous piecewise polynomials in each calendar time unit.
Integer. Number of patients per calendar time unit. Default=25.
ncc
Logical. Indicates whether to include non-concurrent data into the analysis. Default=TRUE.
poly_degree
Integer. Degree of the piecewise polynomial. Default=3.
check
Logical. Indicates whether the input parameters should be checked by the function. Default=TRUE, unless the function is called by a simulation function, where the default is FALSE.
...
Further arguments passed by wrapper functions when running simulations.