This function generates a time trend for given time points in the trial according to a periodic function.
seasonal_trend(j, lambda, n_wave, n_total)Time trend for time points j.
Time points for which the trend should be generated.
Strength of time trend.
How many cycles (waves) should the time trend have (\(\psi\)).
Total sample size in the trial.
Marta Bofill Roig, Pavla Krotka
The time trend is generated according to the function \(f(j) = \lambda \cdot \mathrm{sin} \big( \psi \cdot 2\pi \cdot \frac{j-1}{N-1} \big)\), where \(N\) is the total sample size (parameter n_total) and the parameter \(\psi\) corresponds to the input parameter n_wave.